@@ -1,7 +1,7 @@
 /*
  *   Copyright (C) 2006
  *   Siraj Razick <siraj@kdemail.net>
- *   PhobosK <phobosk@mail.kbfx.org>
+ *   PhobosK <phobosk@mail.kbfx.net>
  *   see Also AUTHORS
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 
 #include <kdebug.h>
 #include <tqstringlist.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kstandarddirs.h>
 #include <tqmap.h>
 #include <tqdir.h>
@@ -35,7 +35,7 @@
 typedef TQMap<TQString, TQString> ThemesMap;
 
 /**
- * @author PhobosK <phobosk@mail.kbfx.org>
+ * @author PhobosK <phobosk@mail.kbfx.net>
  */
 class KbfxThemesData
 {
