@@ -46,10 +46,10 @@ KbfxPlasmaCanvasView::KbfxPlasmaCanvasView ( TQWidget * parent,
 	m_scrollbar_top->setType ( KbfxSpinxScrollBar::UP );
 	m_scrollbar_bot->setType ( KbfxSpinxScrollBar::DOWN );
 
-	connect ( m_scrollbar_top, TQT_SIGNAL ( scroll ( int, int ) ), this,
-	          TQT_SLOT ( scrollBy ( int, int ) ) );
-	connect ( m_scrollbar_bot, TQT_SIGNAL ( scroll ( int, int ) ), this,
-	          TQT_SLOT ( scrollBy ( int, int ) ) );
+	connect ( m_scrollbar_top, TQ_SIGNAL ( scroll ( int, int ) ), this,
+	          TQ_SLOT ( scrollBy ( int, int ) ) );
+	connect ( m_scrollbar_bot, TQ_SIGNAL ( scroll ( int, int ) ), this,
+	          TQ_SLOT ( scrollBy ( int, int ) ) );
 
 	placeScrollBars ();
 }
@@ -174,7 +174,7 @@ KbfxPlasmaCanvasView::contentsMouseMoveEvent ( TQMouseEvent * me )
 	if ( canvas () == NULL )
 		return;
 
-	if ( me->state () & Qt::LeftButton )
+	if ( me->state () & TQt::LeftButton )
 	{
 		int distance = ( me->pos () - m_dragPos ).manhattanLength ();
 		if ( distance > TQApplication::startDragDistance () )
@@ -227,7 +227,7 @@ KbfxPlasmaCanvasView::contentsMousePressEvent ( TQMouseEvent * me )
 		tmp->shade ();
 	m_clickPos = me->pos ();
 
-	if ( me->button () == Qt::LeftButton )
+	if ( me->button () == TQt::LeftButton )
 		m_dragPos = me->pos ();
 	TQScrollView::contentsMousePressEvent ( me );
 	canvas ()->update ();
