@@ -61,12 +61,12 @@ KbfxToolTip::KbfxToolTip ( TQWidget * parent, const char *name, WFlags fl ) :
 	_update_timer = new TQTimer ( this );
 	_move_timer = new TQTimer ( this );
 
-	connect ( _hide_timer, TQT_SIGNAL ( timeout () ), this, TQT_SLOT ( hide () ) );
-	connect ( _hide_timer, TQT_SIGNAL ( timeout () ), _agent, TQT_SLOT ( hide () ) );
-	connect ( _update_timer, TQT_SIGNAL ( timeout () ), this, TQT_SLOT ( logoMove () ) );
+	connect ( _hide_timer, TQ_SIGNAL ( timeout () ), this, TQ_SLOT ( hide () ) );
+	connect ( _hide_timer, TQ_SIGNAL ( timeout () ), _agent, TQ_SLOT ( hide () ) );
+	connect ( _update_timer, TQ_SIGNAL ( timeout () ), this, TQ_SLOT ( logoMove () ) );
 
 	TQCursor kbfxCursor;
-	kbfxCursor.setShape ( Qt::PointingHandCursor );
+	kbfxCursor.setShape ( TQt::PointingHandCursor );
 	this->setCursor ( ( const TQCursor ) kbfxCursor );
 }
 
@@ -266,7 +266,7 @@ KbfxToolTip::paintEvent ( TQPaintEvent * pe )
 
 	TQPainter p;
 	p.begin ( this );
-	p.setBackgroundMode ( Qt::TransparentMode );
+	p.setBackgroundMode ( TQt::TransparentMode );
 	p.drawPixmap ( TQRect ( 7, 16, _dude_box.width (), _dude_box.height () ),
 	               _dude_box );
 	int _paddingX = ( ( _dude_box.height () - _dude.height () ) / 2 ) + 16;
